@@ -27,11 +27,11 @@ from setuptools import __version__ as setuptools_version
 
 modname = distname = 'pylint'
 
-numversion = (1, 8, 1)
+numversion = (1, 8, 2)
 version = '.'.join([str(num) for num in numversion])
 
 install_requires = [
-    'astroid<2.0',
+    'astroid>=1.6,<2.0',
     'six',
     'isort >= 4.2.5',
     'mccabe',
